@@ -32,14 +32,4 @@ void fft512(t_fft *x)
   fft<512,1>(x);
 }
 
-void fftr384(t_fft *x) 
-{
-  fftr<384,1>(x);
-}
-
-void fftr512(t_fft *x) 
-{
-  fftr<512,1>(x);
-}
-
 }
