@@ -3,7 +3,6 @@
 #define UTILS_H
 
 #include "real.h"
-#include "config.h"
 #include "sbsms.h"
 
 namespace _sbsms_ {
@@ -17,13 +16,11 @@ inline void c2even(audio *eo, audio *even, int N)
   int Nover2 = N/2;
   even[0][0] = eo[0][0];
   even[0][1] = 0.0f;
-  for(int k=1;k<Nover2;k++) {
+  for(int k=1;k<=Nover2;k++) {
     int Nk = N-k;
     even[k][0] = 0.5f*(eo[k][0] + eo[Nk][0]);
     even[k][1] = 0.5f*(eo[k][1] - eo[Nk][1]);
   }
-  even[Nover2][0] = eo[Nover2][0];
-  even[Nover2][1] = 0.0f;
 }
 
 inline void c2odd(audio *eo, audio *odd, int N)
@@ -31,13 +28,11 @@ inline void c2odd(audio *eo, audio *odd, int N)
   int Nover2 = N/2;
   odd[0][0] = eo[0][1];
   odd[0][1] = 0.0f;
-  for(int k=1;k<Nover2;k++) {
+  for(int k=1;k<=Nover2;k++) {
     int Nk = N-k;
     odd[k][0] = 0.5f*(eo[k][1] + eo[Nk][1]);
     odd[k][1] = 0.5f*(eo[Nk][0] - eo[k][0]);
   }
-  odd[Nover2][0] = 0.0f;
-  odd[Nover2][1] = eo[Nover2][1];
 }
 
 inline float canonPI(float ph) 
